@@ -29,7 +29,7 @@ class SourceView(ptah.View):
         while 1:
             try:
                 dist = pkg_resources.get_distribution(pkg_name)
-                if dist is not None:
+                if dist is not None: # pragma: no cover
                     break
             except pkg_resources.DistributionNotFound:
                 if '.' not in pkg_name:
@@ -53,20 +53,25 @@ class SourceView(ptah.View):
             source = open(abspath, 'rb').read()
 
             if not self.format:
-                from pygments import highlight
-                from pygments.lexers import PythonLexer
-                from pygments.formatters import HtmlFormatter
+                try:
+                    from pygments import highlight
+                    from pygments.lexers import PythonLexer
+                    from pygments.formatters import HtmlFormatter
 
-                html = HtmlFormatter(
-                    linenos='inline',
-                    lineanchors='sl',
-                    anchorlinenos=True,
-                    noclasses = True,
-                    cssclass="ptah-source")
+                    html = HtmlFormatter(
+                        linenos='inline',
+                        lineanchors='sl',
+                        anchorlinenos=True,
+                        noclasses = True,
+                        cssclass="ptah-source")
 
-                def format(self, code, highlight=highlight,
-                           lexer = PythonLexer()):
-                    return highlight(code, lexer, html)
+                    def format(self, code, highlight=highlight,
+                               lexer = PythonLexer()):
+                        return highlight(code, lexer, html)
+
+                except ImportError: # pragma: no cover
+                    def format(self, text):
+                        return '<pre>%s</pre>'%text
 
                 self.__class__.format = format
 
